// lib/pages/routiens/widgets/then_container.dart

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/routiens/bloc/routine_bloc.dart';
import 'package:syncrow_web/pages/routiens/helper/dialog_helper/device_dialog_helper.dart';
import 'package:syncrow_web/pages/routiens/widgets/dragable_card.dart';

class ThenContainer extends StatelessWidget {
  const ThenContainer({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<RoutineBloc, RoutineState>(
      builder: (context, state) {
        return DragTarget<Map<String, dynamic>>(
          builder: (context, candidateData, rejectedData) {
            return Container(
              padding: const EdgeInsets.all(16),
              width: double.infinity,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Text('THEN',
                      style:
                          TextStyle(fontSize: 18, fontWeight: FontWeight.bold)),
                  const SizedBox(height: 16),
                  Wrap(
                    spacing: 8,
                    runSpacing: 8,
                    children: state.thenItems
                        .map((item) => DraggableCard(
                              key: Key(item['key']!),
                              imagePath: item['imagePath']!,
                              title: item['title']!,
                            ))
                        .toList(),
                  ),
                ],
              ),
            );
          },
          onWillAccept: (data) => data != null,
          onAccept: (data) async {
            final result =
                await DeviceDialogHelper.showDeviceDialog(context, data);
            if (result != null) {
              context.read<RoutineBloc>().add(AddToThenContainer(result));
            } else if (!['AC', '1G', '2G', '3G']
                .contains(data['productType'])) {
              context.read<RoutineBloc>().add(AddToThenContainer(data));
            }
          },
        );
      },
    );
  }
}
